@@ -6,7 +6,7 @@ from sentry_sdk.integrations.redis import RedisIntegration
 
 from fief import __version__
 from fief.apps import admin_app, admin_frontend_app, auth_app
-from fief.db.account import account_engine_manager
+from fief.db.workspace import workspace_engine_manager
 from fief.settings import settings
 
 sentry_sdk.init(
@@ -34,7 +34,7 @@ app.mount("/", auth_app)
 
 @app.on_event("shutdown")
 async def on_shutdown():
-    await account_engine_manager.close_all()
+    await workspace_engine_manager.close_all()
 
 
 __all__ = ["app"]
